.. _utils:

Utility functions
=================

RosettaSciIO provides certain utility functions that are applicable for multiple
formats, e.g. for the HDF5-format on which a number of plugins are based.

.. _hdf5-utils:

HDF5 utility functions
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: rsciio.utils.hdf5
   :members:


Test utility functions
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: rsciio.tests.registry_utils
   :members: